@@ -1,25 +1,11 @@
 /*
- * Copyright (c) 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
- * Copyright (c) 2006, 2007 Riccardo Iaconelli <riccardo@kde.org>
- * Copyright (c) 2006, 2007 Casper Boemann <cbr@boemann.dk>
- * Copyright (c) 2015 David Edmundson <davidedmundson@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+    SPDX-FileCopyrightText: 2006, 2007 Riccardo Iaconelli <riccardo@kde.org>
+    SPDX-FileCopyrightText: 2006, 2007 Casper Boemann <cbr@boemann.dk>
+    SPDX-FileCopyrightText: 2015 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "oxygenbutton.h"
 #include "oxygensettingsprovider.h"
@@ -222,7 +208,7 @@ namespace Oxygen
         if( m_flag == FlagFirstInList ) painter->translate( m_offset );
         else painter->translate( 0, m_offset.y() );
 
-        if( !m_iconSize.isValid() ) m_iconSize = geometry().size().toSize();
+        if( !m_iconSize.isValid() || isStandAlone() ) m_iconSize = geometry().size().toSize();
 
         // menu buttons
         if( isMenuButton() )
