@@ -3,25 +3,9 @@
 // stores event filters and maps widgets to timelines for animations
 // -------------------
 //
-// Copyright (c) 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+// SPDX-FileCopyrightText: 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 //
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-//
-// The above copyright notice and this permission notice shall be included in
-// all copies or substantial portions of the Software.
-//
-// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
-// IN THE SOFTWARE.
+// SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenmenubarengine.h"
@@ -37,7 +21,8 @@ namespace Oxygen
     {
         if( other )
         {
-            foreach( QWidget* widget,  other->registeredWidgets() )
+            const auto otherWidgets = other->registeredWidgets();
+            for ( QWidget *widget : otherWidgets )
             { registerWidget( widget ); }
         }
     }
@@ -74,7 +59,7 @@ namespace Oxygen
 
         // the typedef is needed to make Krazy happy
         typedef DataMap<MenuBarDataV1>::Value Value;
-        foreach( const Value& value, _data )
+        for ( const Value &value : std::as_const(_data) )
         { if( value ) out.insert( value.data()->target().data() ); }
 
         return out;
@@ -88,7 +73,8 @@ namespace Oxygen
     {
         if( other )
         {
-            foreach( QWidget* widget, other->registeredWidgets() )
+            const auto otherWidgets = other->registeredWidgets();
+            for ( QWidget *widget : otherWidgets )
             { registerWidget( widget ); }
         }
     }
@@ -159,7 +145,7 @@ namespace Oxygen
 
         // the typedef is needed to make Krazy happy
         typedef DataMap<MenuBarDataV2>::Value Value;
-        foreach( const Value& value, _data )
+        for ( const Value &value : std::as_const(_data) )
         { if( value ) out.insert( value.data()->target().data() ); }
 
         return out;
